@@ -1,45 +1,17 @@
-#
-# views.py -- Views for the authentication app
-#
-# Copyright (c) 2007-2009  Christian Hammond
-# Copyright (c) 2007-2009  David Trowbridge
-# Copyright (C) 2007 Micah Dowty
-#
-# Permission is hereby granted, free of charge, to any person obtaining
-# a copy of this software and associated documentation files (the
-# "Software"), to deal in the Software without restriction, including
-# without limitation the rights to use, copy, modify, merge, publish,
-# distribute, sublicense, and/or sell copies of the Software, and to
-# permit persons to whom the Software is furnished to do so, subject to
-# the following conditions:
-#
-# The above copyright notice and this permission notice shall be included
-# in all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
-# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
-# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
-# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
-# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
-# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
 """Authentication-related views.
 
 The bundled views help with common authentication-related tasks not otherwise
 provided by Django. At the moment, there is only support here for registration.
 """
 
-from __future__ import unicode_literals
-
 from django.contrib import auth
 from django.http import HttpResponseRedirect
+from django.shortcuts import render
 from django.views.decorators.csrf import csrf_protect
 
 from djblets.auth.forms import RegistrationForm
 from djblets.auth.signals import user_registered
 from djblets.auth.util import validate_test_cookie
-from djblets.util.compat.django.shortcuts import render
 
 
 @csrf_protect
