@@ -1,8 +1,6 @@
-from __future__ import unicode_literals
 import json
 
 from django.core.exceptions import ValidationError
-from django.utils import six
 
 
 def validate_json(value):
@@ -12,8 +10,8 @@ def validate_json(value):
     (representing a serialized JSON payload, possibly from the admin UI)
     and cannot be loaded properly.
     """
-    if isinstance(value, six.string_types):
+    if isinstance(value, str):
         try:
             json.loads(value)
         except ValueError as e:
-            raise ValidationError(six.text_type(e), code='invalid')
+            raise ValidationError(str(e), code='invalid')
