@@ -7,58 +7,47 @@ The contents in this file might change substantially between releases. If
 you're going to make use of data from this file, code defensively.
 """
 
-from __future__ import unicode_literals
-
 # NOTE: This file may not import other files! It's used for packaging and
 #       may be needed before any dependencies have been installed.
 
 
-#: The minimum supported version of Python 2.x.
-PYTHON_2_MIN_VERSION = (2, 7)
-
 #: The minimum supported version of Python 3.x.
-PYTHON_3_MIN_VERSION = (3, 6)
-
-#: A string representation of the minimum supported version of Python 2.x.
-PYTHON_2_MIN_VERSION_STR = '%s.%s' % (PYTHON_2_MIN_VERSION)
+PYTHON_3_MIN_VERSION = (3, 7)
 
 #: A string representation of the minimum supported version of Python 3.x.
-PYTHON_3_MIN_VERSION_STR = '%s.%s' % (PYTHON_3_MIN_VERSION)
-
-#: A dependency version range for Python 2.x.
-PYTHON_2_RANGE = "=='%s.*'" % PYTHON_2_MIN_VERSION_STR
+PYTHON_3_MIN_VERSION_STR = '%s.%s' % PYTHON_3_MIN_VERSION
 
 #: A dependency version range for Python 3.x.
 PYTHON_3_RANGE = ">='%s'" % PYTHON_3_MIN_VERSION_STR
 
 
 #: The major version of Django we're using for documentation.
-django_doc_major_version = '1.6'
+django_doc_major_version = '3.2'
 
 #: The major version of Review Board we're using for documentation.
 reviewboard_doc_major_version = 'dev'
 
 #: The version range required for Django.
-django_version = '>=1.6.11,<1.11.999'
+django_version = '~=3.2.16'
 
 #: Dependencies required for LessCSS pipelining.
 lesscss_npm_dependencies = {
-    'less': '^3.11.0',
-    '@beanbag/less-plugin-autoprefix': '^2.0.1',
+    'less': '^4.1.3',
+    '@beanbag/less-plugin-autoprefix': '^3.0.0',
 }
 
 #: Dependencies required for UglifyJS JavaScript compression.
 uglifyjs_npm_dependencies = {
-    'uglify-js': '^3.6.0',
+    'uglify-js': '^3.16.1',
 }
 
 #: Dependencies required for Babel for JavaScript.
 babel_npm_dependencies = {
-    '@babel/cli': '^7.15.4',
-    '@babel/core': '^7.15.5',
-    '@babel/preset-env': '^7.15.6',
+    '@babel/cli': '^7.17.10',
+    '@babel/core': '^7.18.5',
+    '@babel/preset-env': '^7.18.2',
     'babel-plugin-dedent': '^2.1.0',
-    'babel-plugin-django-gettext': '^1.1.0',
+    'babel-plugin-django-gettext': '^1.1.1',
 }
 
 #: All static media dependencies required to package/develop against  Djblets.
@@ -69,49 +58,14 @@ npm_dependencies.update(babel_npm_dependencies)
 
 #: All dependencies required to install Djblets.
 package_dependencies = {
+    'cryptography': '>=1.8.1',
     'Django': django_version,
-    'django-pipeline': '>=1.6.14,<1.6.999',
-    'dnspython': [
-        {
-            'python': PYTHON_2_RANGE,
-            'version': '>=1.14.0,<1.999',
-        },
-        {
-            'python': PYTHON_3_RANGE,
-            'version': '>=1.14.0',
-        },
-    ],
-    'feedparser': [
-        {
-            'python': PYTHON_2_RANGE,
-            'version': '>=5.1.2,<5.999',
-        },
-        {
-            'python': PYTHON_3_RANGE,
-            'version': '>=5.1.2',
-        },
-    ],
-    'Pillow': [
-        {
-            'python': PYTHON_2_RANGE,
-            'version': '>=6.2,<6.999',
-        },
-        {
-            'python': PYTHON_3_RANGE,
-            'version': '>=6.2',
-        },
-    ],
+    'django-pipeline': '~=2.0.8',
+    'dnspython': '>=1.14.0',
+    'feedparser': '>=5.1.2',
+    'Pillow': '>=6.2',
     'publicsuffix': '>=1.1',
-    'python-dateutil': [
-        {
-            'python': PYTHON_2_RANGE,
-            'version': '>=2.7',
-        },
-        {
-            'python': PYTHON_3_RANGE,
-            'version': '>=2.7',
-        },
-    ],
+    'python-dateutil': '>=2.7',
     'pytz': '',
 }
 
