@@ -1,7 +1,5 @@
 """Extension manager class for supporting extensions to an application."""
 
-from __future__ import unicode_literals
-
 import atexit
 import errno
 import logging
@@ -16,17 +14,16 @@ import traceback
 import warnings
 import weakref
 from contextlib import contextmanager
-from importlib import import_module
+from importlib import import_module, reload
 
+from django.apps.registry import apps
 from django.conf import settings
-from django.conf.urls import include, url
 from django.contrib.admin.sites import AdminSite
-from django.core.urlresolvers import reverse
+from django.core.files import locks
 from django.db import IntegrityError
-from django.utils import six
+from django.urls import include, path, reverse
 from django.utils.module_loading import module_has_submodule
-from django.utils.six.moves import reload_module
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 from pipeline.conf import settings as pipeline_settings
 from setuptools.command import easy_install
 
@@ -35,15 +32,6 @@ try:
 except ImportError:
     Evolver = None
 
-try:
-    # Django >= 1.7
-    from django.apps.registry import apps
-except ImportError:
-    # Django == 1.6
-    from django.db.models import loading
-
-    apps = None
-
 from djblets.cache.synchronizer import GenerationSynchronizer
 from djblets.extensions.errors import (EnablingExtensionError,
                                        InstallExtensionError,
@@ -58,7 +46,6 @@ from djblets.extensions.signals import (extension_disabled,
 from djblets.template.caches import (clear_template_caches,
                                      clear_template_tag_caches)
 from djblets.urls.resolvers import DynamicURLResolver
-from djblets.util.compat.django.core.files import locks
 
 
 logger = logging.getLogger(__name__)
@@ -288,23 +275,16 @@ class ExtensionManager(object):
 
         # Extension middleware instances, ordered by dependencies.
         self.middleware_classes = []
-        self.legacy_middleware_instances = []
 
         # Wrap the INSTALLED_APPS and TEMPLATE_CONTEXT_PROCESSORS settings
         # to allow for ref-counted add/remove operations.
         self._installed_apps_setting = SettingListWrapper('INSTALLED_APPS',
                                                           'installed app')
 
-        if hasattr(settings, 'TEMPLATES'):
-            # Django >= 1.7
-            self._context_processors_setting = SettingListWrapper(
-                'context_processors',
-                'context processor',
-                parent_dict=settings.TEMPLATES[0]['OPTIONS'])
-        else:
-            self._context_processors_setting = SettingListWrapper(
-                'TEMPLATE_CONTEXT_PROCESSORS',
-                'context processor')
+        self._context_processors_setting = SettingListWrapper(
+            'context_processors',
+            'context processor',
+            parent_dict=settings.TEMPLATES[0]['OPTIONS'])
 
         instance_id = id(self)
         _extension_managers[instance_id] = self
@@ -473,7 +453,7 @@ class ExtensionManager(object):
         """
         # This will raise InvalidExtensionError if not found.
         dependency = self.get_installed_extension(dependency_extension_id)
-        extension_classes = six.iteritems(self._extension_classes)
+        extension_classes = self._extension_classes.items()
 
         return [
             extension_id
@@ -785,7 +765,7 @@ class ExtensionManager(object):
 
         # Now we have all the RegisteredExtension instances. Go through
         # and initialize each of them.
-        for class_name, registered_ext in six.iteritems(found_registrations):
+        for class_name, registered_ext in found_registrations.items():
             ext_class = found_extensions[class_name]
             ext_class.registration = registered_ext
 
@@ -809,7 +789,7 @@ class ExtensionManager(object):
         # While we're at it, since we're at a point where we've seen all
         # extensions, we can set the ExtensionInfo.requirements for
         # each extension
-        for class_name, ext_class in six.iteritems(self._extension_classes):
+        for class_name, ext_class in self._extension_classes.items():
             if class_name not in found_extensions:
                 if class_name in self._extension_instances:
                     self.disable_extension(class_name)
@@ -1026,7 +1006,7 @@ class ExtensionManager(object):
                                  ext_class.id, e)
 
                 raise InstallExtensionError(
-                    six.text_type(e),
+                    str(e),
                     self._store_load_error(ext_class.id, e))
 
     def _get_app_modules_with_models(self, app_names):
@@ -1045,28 +1025,18 @@ class ExtensionManager(object):
         """
         results = []
 
-        if apps:
-            # Django >= 1.7
+        # There's no way of looking up an AppConfig based on the app
+        # name, so we'll need to start by building our own map.
+        all_app_configs = {
+            app_config.name: app_config
+            for app_config in apps.get_app_configs()
+        }
 
-            # There's no way of looking up an AppConfig based on the app
-            # name, so we'll need to start by building our own map.
-            all_app_configs = {
-                app_config.name: app_config
-                for app_config in apps.get_app_configs()
-            }
+        for app_name in app_names:
+            app_config = all_app_configs[app_name]
 
-            for app_name in app_names:
-                app_config = all_app_configs[app_name]
-
-                if app_config.models and app_config.models_module:
-                    results.append(app_config.models_module)
-        else:
-            # Django == 1.6
-            for app_name in app_names:
-                app = loading.load_app(app_name)
-
-                if app is not None:
-                    results.append(app)
+            if app_config.models and app_config.models_module:
+                results.append(app_config.models_module)
 
         return results
 
@@ -1368,10 +1338,10 @@ class ExtensionManager(object):
         extension.registration.installed = False
         extension.registration.save()
 
-        for path in (extension.info.installed_htdocs_path,
-                     extension.info.installed_static_path):
-            if os.path.exists(path):
-                shutil.rmtree(path, ignore_errors=True)
+        for media_path in (extension.info.installed_htdocs_path,
+                           extension.info.installed_static_path):
+            if os.path.exists(media_path):
+                shutil.rmtree(media_path, ignore_errors=True)
 
     def _install_admin_urls(self, extension):
         """Install administration URLs.
@@ -1399,16 +1369,16 @@ class ExtensionManager(object):
 
             if hasattr(urlconf, 'urlpatterns'):
                 extension.admin_urlpatterns = [
-                    url(r'^%s%s/config/' % (prefix, extension.id),
-                        include(urlconf.__name__)),
+                    path('%s%s/config/' % (prefix, extension.id),
+                         include(urlconf.__name__)),
                 ]
 
                 self.dynamic_urls.add_patterns(extension.admin_urlpatterns)
 
         if getattr(extension, 'admin_site', None):
             extension.admin_site_urlpatterns = [
-                url(r'^%s%s/db/' % (prefix, extension.id),
-                    include(extension.admin_site.urls)),
+                path('%s%s/db/' % (prefix, extension.id),
+                     extension.admin_site.urls)
             ]
 
             self.dynamic_urls.add_patterns(extension.admin_site_urlpatterns)
@@ -1429,7 +1399,7 @@ class ExtensionManager(object):
 
         def _add_bundles(pipeline_bundles, extension_bundles, default_dir,
                          ext):
-            for name, bundle in six.iteritems(extension_bundles):
+            for name, bundle in extension_bundles.items():
                 new_bundle = bundle.copy()
 
                 new_bundle['source_filenames'] = [
@@ -1461,7 +1431,7 @@ class ExtensionManager(object):
                 unregister.
         """
         def _remove_bundles(pipeline_bundles, extension_bundles):
-            for name, bundle in six.iteritems(extension_bundles):
+            for name, bundle in extension_bundles.items():
                 try:
                     del pipeline_bundles[extension.get_bundle_id(name)]
                 except KeyError:
@@ -1498,7 +1468,7 @@ class ExtensionManager(object):
                 # If the extension has been loaded previously and we are
                 # re-enabling it, we must reload the module. Just importing
                 # again will not cause the ModelAdmins to be registered.
-                reload_module(sys.modules[admin_module_name])
+                reload(sys.modules[admin_module_name])
             else:
                 import_module(admin_module_name)
         except ImportError:
@@ -1525,12 +1495,7 @@ class ExtensionManager(object):
         new_installed_apps = extension.apps or [extension.info.app_name]
         self._installed_apps_setting.add_list(new_installed_apps)
 
-        if apps:
-            # Django >= 1.7
-            apps.set_installed_apps(settings.INSTALLED_APPS)
-        else:
-            # Django == 1.6
-            loading.cache.loaded = False
+        apps.set_installed_apps(settings.INSTALLED_APPS)
 
         return new_installed_apps
 
@@ -1545,63 +1510,11 @@ class ExtensionManager(object):
                 The extension whose apps are being removed.
         """
         # Remove the extension's apps from INSTALLED_APPS.
-        removed_apps = self._installed_apps_setting.remove_list(
+        self._installed_apps_setting.remove_list(
             extension.apps or [extension.info.app_name])
 
         # Now clear the apps and their modules from any caches.
-        if apps:
-            apps.unset_installed_apps()
-        else:
-            had_models = False
-
-            for app_name in removed_apps:
-                # In Django 1.6, the only apps that are registered are those
-                # with models. If this particular app does not have models, we
-                # don't want to clear any caches below. There might be another
-                # app with the same label that actually does have models, and
-                # we'd be clearing those away. An example would be
-                # reviewboard.hostingsvcs (which has models) and
-                # rbpowerpack.hostingsvcs (which does not).
-                #
-                # Django 1.6 doesn't technically allow multiple apps with the
-                # same label to have models (other craziness will happen), so
-                # we don't have to worry about that. It's not our problem.
-                try:
-                    app_mod = import_module('%s.models' % app_name)
-                except ImportError:
-                    # Something went very wrong. Maybe this module didn't
-                    # exist anymore. Ignore it.
-                    continue
-
-                # Fetch the models before we make any changes to the cache.
-                model_modules = {app_mod}
-                model_modules.update(
-                    import_module(model.__module__)
-                    for model in loading.get_models(app_mod)
-                )
-
-                # Start pruning this app from the caches.
-                #
-                # We are going to keep this in loading.cache.app_models.
-                # If we don't, we'll never get those modules again without
-                # some potentially dangerous manipulation of sys.modules and
-                # possibly other state. get_models() will default to ignoring
-                # anything in that list if the app label isn't present in
-                # loading.cache.app_labels, which we'll remove, so the model
-                # will appear as "uninstalled."
-                app_label = app_name.rpartition('.')[2]
-                loading.cache.app_labels.pop(app_label, None)
-
-                for module in model_modules:
-                    loading.cache.app_store.pop(module, None)
-
-                had_models = True
-
-            if had_models:
-                # Force get_models() to recompute models for lookups, so that
-                # now-unregistered models aren't returned.
-                loading.cache._get_models_cache.clear()
-                loading.cache.loaded = False
+        apps.unset_installed_apps()
 
     def _entrypoint_iterator(self):
         """Iterate through registered Python entry points.
@@ -1646,13 +1559,10 @@ class ExtensionManager(object):
         Django settings and will be used for future requests.
         """
         self.middleware_classes = []
-        self.legacy_middleware_instances = []
         done = set()
 
         for e in self.get_enabled_extensions():
-            mw, legacy_mw = self._get_extension_middleware(e, done)
-            self.middleware_classes += mw
-            self.legacy_middleware_instances += legacy_mw
+            self.middleware_classes += self._get_extension_middleware(e, done)
 
     def _get_extension_middleware(self, extension, done):
         """Return a list of middleware for an extension and its dependencies.
@@ -1671,13 +1581,10 @@ class ExtensionManager(object):
                 found that exist in this set will be ignored.
 
         Returns:
-            tuple of list:
-            A 2-tuple of lists. The first list is a list of classes for
-            new-style (Django 1.10+) middleware. The second list is a list of
-            instances for old-style middleware.
+            list:
+            A list of classes for middleware.
         """
         middleware = []
-        legacy_middleware = []
 
         if extension in done:
             return middleware
@@ -1688,13 +1595,10 @@ class ExtensionManager(object):
             e = self.get_enabled_extension(req)
 
             if e:
-                mw, legacy_mw = self._get_extension_middleware(e, done)
-                middleware += mw
-                legacy_middleware += legacy_mw
+                middleware += self._get_extension_middleware(e, done)
 
         middleware.extend(extension.middleware_classes)
-        legacy_middleware.extend(extension.legacy_middleware_instances)
-        return middleware, legacy_middleware
+        return middleware
 
     @contextmanager
     def _open_lock_file(self, ext_class, filename,
@@ -1763,7 +1667,7 @@ def get_extension_managers():
         list of ExtensionManager:
         The list of all extension manager instances currently registered.
     """
-    return list(six.itervalues(_extension_managers))
+    return list(_extension_managers.values())
 
 
 def shutdown_extension_managers():
