@@ -1,8 +1,5 @@
-from __future__ import unicode_literals
-
 import copy
 
-from django.utils import six
 from django.utils.datastructures import MultiValueDict
 
 from djblets.conditions.choices import (BaseConditionChoice,
@@ -239,7 +236,7 @@ class ConditionsWidgetTests(TestCase):
 
         # Check the first rendered row.
         rendered_row = rendered_rows[0]
-        self.assertEqual(set(six.iterkeys(rendered_row)),
+        self.assertEqual(set(rendered_row.keys()),
                          {'choice', 'operator', 'error'})
 
         self.assertHTMLEqual(
@@ -265,7 +262,7 @@ class ConditionsWidgetTests(TestCase):
 
         # Check the second rendered row.
         rendered_row = rendered_rows[1]
-        self.assertEqual(set(six.iterkeys(rendered_row)),
+        self.assertEqual(set(rendered_row.keys()),
                          {'choice', 'operator', 'error'})
 
         self.assertHTMLEqual(
@@ -293,7 +290,7 @@ class ConditionsWidgetTests(TestCase):
 
         # Check the first serialized choice.
         serialized_choice = serialized_choices[0]
-        self.assertEqual(set(six.iterkeys(serialized_choice)),
+        self.assertEqual(set(serialized_choice.keys()),
                          {'id', 'name', 'valueField', 'operators'})
         self.assertEqual(serialized_choice['id'], 'my-choice-1')
         self.assertEqual(serialized_choice['name'], 'My Choice 1')
@@ -305,14 +302,14 @@ class ConditionsWidgetTests(TestCase):
 
         # Check the first operator in the first serialized choice.
         serialized_operator = serialized_operators[0]
-        self.assertEqual(set(six.iterkeys(serialized_operator)),
+        self.assertEqual(set(serialized_operator.keys()),
                          {'id', 'name', 'useValue', 'valueField'})
         self.assertEqual(serialized_operator['id'], 'my-op-1')
         self.assertEqual(serialized_operator['name'], 'My Op 1')
         self.assertTrue(serialized_operator['useValue'])
 
         serialized_value_field = serialized_operator['valueField']
-        self.assertEqual(set(six.iterkeys(serialized_value_field)),
+        self.assertEqual(set(serialized_value_field.keys()),
                          {'model', 'view'})
 
         serialized_value_model = serialized_value_field['model']
@@ -328,14 +325,14 @@ class ConditionsWidgetTests(TestCase):
 
         # Check the second operator in the first serialized choice.
         serialized_operator = serialized_operators[1]
-        self.assertEqual(set(six.iterkeys(serialized_operator)),
+        self.assertEqual(set(serialized_operator.keys()),
                          {'id', 'name', 'useValue', 'valueField'})
         self.assertEqual(serialized_operator['id'], 'my-op-2')
         self.assertEqual(serialized_operator['name'], 'My Op 2')
         self.assertTrue(serialized_operator['useValue'])
 
         serialized_value_field = serialized_operator['valueField']
-        self.assertEqual(set(six.iterkeys(serialized_value_field)),
+        self.assertEqual(set(serialized_value_field.keys()),
                          {'model', 'view'})
 
         serialized_value_model = serialized_value_field['model']
@@ -423,7 +420,7 @@ class ConditionsWidgetTests(TestCase):
         self.assertEqual(len(rendered_rows), 1)
 
         rendered_row = rendered_rows[0]
-        self.assertEqual(set(six.iterkeys(rendered_row)),
+        self.assertEqual(set(rendered_row.keys()),
                          {'choice', 'operator', 'error'})
         self.assertHTMLEqual(
             rendered_row['choice'],
@@ -502,7 +499,7 @@ class ConditionsWidgetTests(TestCase):
         self.assertEqual(len(rendered_rows), 1)
 
         rendered_row = rendered_rows[0]
-        self.assertEqual(set(six.iterkeys(rendered_row)),
+        self.assertEqual(set(rendered_row.keys()),
                          {'choice', 'operator', 'error'})
         self.assertHTMLEqual(
             rendered_row['choice'],
@@ -581,7 +578,7 @@ class ConditionsWidgetTests(TestCase):
         self.assertEqual(len(rendered_rows), 1)
 
         rendered_row = rendered_rows[0]
-        self.assertEqual(set(six.iterkeys(rendered_row)),
+        self.assertEqual(set(rendered_row.keys()),
                          {'choice', 'operator', 'error'})
         self.assertHTMLEqual(
             rendered_row['choice'],
@@ -652,11 +649,11 @@ class ConditionsWidgetTests(TestCase):
         self.assertIn('<input type="hidden" name="my_conditions_last_id"'
                       ' value="1">',
                       rendered)
-        self.assertRegexpMatches(
+        self.assertRegex(
             rendered,
             '<option value="my-choice" selected(="selected")?>My Choice'
             '</option>')
-        self.assertRegexpMatches(
+        self.assertRegex(
             rendered,
             '<option value="my-op" selected(="selected")?>My Op</option>')
         self.assertIn('<span class="conditions-field-value"></span>',
