@@ -1,8 +1,6 @@
 """Exceptions for integrations."""
 
-from __future__ import unicode_literals
-
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 
 
 class IntegrationError(Exception):
