@@ -1,12 +1,6 @@
 """App configuration for djblets.privacy."""
 
-from __future__ import unicode_literals
-
-try:
-    from django.apps import AppConfig
-except ImportError:
-    # Django < 1.7
-    AppConfig = object
+from django.apps import AppConfig
 
 
 class PrivacyAppConfig(AppConfig):
