@@ -1,18 +1,16 @@
 """Forms, fields, and widgets for gathering and displaying consent."""
 
-from __future__ import unicode_literals
-
 from django import forms
 from django.contrib import messages
 from django.forms.widgets import MultiWidget, Widget
+from django.template.loader import render_to_string
 from django.utils import timezone
 from django.utils.html import format_html_join
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from djblets.privacy.consent import (Consent,
                                      get_consent_requirements_registry,
                                      get_consent_tracker)
-from djblets.util.compat.django.template.loader import render_to_string
 
 
 class ConsentRequirementWidget(Widget):
@@ -43,7 +41,7 @@ class ConsentRequirementWidget(Widget):
 
         self.consent_requirement = consent_requirement
 
-    def render(self, name, value, attrs=None):
+    def render(self, name, value, attrs=None, renderer=None):
         """Render the widget.
 
         Args:
@@ -58,6 +56,9 @@ class ConsentRequirementWidget(Widget):
                 HTML attributes for the widget. This is used only to set an
                 ``id`` attribute for the field.
 
+            renderer (django.forms.renderers.BaseRenderer, optional):
+                The form renderer.
+
         Returns:
             django.utils.safestring.SafeText:
             The rendered HTML for the widget.
@@ -129,7 +130,7 @@ class MultiConsentRequirementsWidget(MultiWidget):
             ],
             attrs=attrs)
 
-    def render(self, name, value, attrs=None):
+    def render(self, name, value, attrs=None, renderer=None):
         """Render the widget.
 
         Args:
@@ -144,6 +145,9 @@ class MultiConsentRequirementsWidget(MultiWidget):
                 HTML attributes for the widget. This is used only to set a
                 base ``id`` attribute for the fields.
 
+            renderer (django.forms.renderers.BaseRenderer, optional):
+                The form renderer.
+
         Returns:
             django.utils.safestring.SafeText:
             The rendered HTML for the widget.
@@ -169,7 +173,8 @@ class MultiConsentRequirementsWidget(MultiWidget):
                                    id='%s_%s' % (field_id, requirement_id))
 
             rendered = widget.render('%s_%s' % (name, requirement_id),
-                                     widget_value, final_attrs)
+                                     widget_value, final_attrs,
+                                     renderer=renderer)
             output.append((rendered,))
 
         return format_html_join('', '{0}', output)
@@ -282,7 +287,7 @@ class ConsentRequirementField(forms.ChoiceField):
         self.extra_consent_data = extra_consent_data
         self.widget.consent_requirement = consent_requirement
 
-        if user and user.is_authenticated():
+        if user and user.is_authenticated:
             self.set_initial_from_user(user)
 
     def set_initial_from_user(self, user):
@@ -296,7 +301,7 @@ class ConsentRequirementField(forms.ChoiceField):
                 The user viewing the form.
         """
         assert user
-        assert user.is_authenticated()
+        assert user.is_authenticated
 
         self.initial = self.consent_requirement.get_consent(user)
 
@@ -405,7 +410,7 @@ class MultiConsentRequirementsField(forms.MultiValueField):
             widget=self.widget(self.consent_requirements),
             *args, **kwargs)
 
-        if user and user.is_authenticated():
+        if user and user.is_authenticated:
             self.set_initial_from_user(user)
 
     def set_initial_from_user(self, user):
@@ -419,7 +424,7 @@ class MultiConsentRequirementsField(forms.MultiValueField):
                 The user viewing the form.
         """
         assert user
-        assert user.is_authenticated()
+        assert user.is_authenticated
 
         self.initial = [
             field.consent_requirement.get_consent(user)
@@ -558,7 +563,7 @@ class ConsentFormMixin(object):
         """
         assert self.is_valid()
         assert user
-        assert user.is_authenticated()
+        assert user.is_authenticated
 
         get_consent_tracker().record_consent_data_list(
             user,
