@@ -1,7 +1,5 @@
 """Signals for being notified on registry operations."""
 
-from __future__ import unicode_literals
-
 from django.dispatch import Signal
 
 
@@ -10,4 +8,4 @@ from django.dispatch import Signal
 #: Args:
 #:     registry (djblets.registries.registry.Registry):
 #:         The registry being populated.
-registry_populating = Signal(providing_args=['registry'])
+registry_populating = Signal()
