@@ -1,11 +1,10 @@
-#
-# Settings for djblets.
-#
-# This is meant for internal use only. We use it primarily for building
-# static media to bundle with djblets.
-#
-# This should generally not be used in a project.
-from __future__ import unicode_literals
+"""Settings for djblets.
+
+This is meant for internal use only. We use it primarily for building
+static media to bundle with djblets.
+
+This should generally not be used in a project.
+"""
 
 import os
 
@@ -21,7 +20,9 @@ DEBUG = False
 DJBLETS_ROOT = os.path.abspath(os.path.dirname(__file__))
 HTDOCS_ROOT = os.path.join(DJBLETS_ROOT, 'htdocs')
 STATIC_ROOT = os.path.join(HTDOCS_ROOT, 'static')
-STATIC_URL = '/'
+MEDIA_ROOT = os.path.join(HTDOCS_ROOT, 'media')
+STATIC_URL = '/static/'
+MEDIA_URL = '/media/'
 LOGIN_LIMIT_RATE = '5/m'
 
 STATICFILES_DIRS = (
@@ -32,7 +33,7 @@ STATICFILES_FINDERS = (
     'django.contrib.staticfiles.finders.FileSystemFinder',
 )
 
-STATICFILES_STORAGE = 'pipeline.storage.PipelineCachedStorage'
+STATICFILES_STORAGE = 'djblets.pipeline.storage.PipelineStorage'
 
 
 NODE_PATH = os.path.abspath(os.path.join(DJBLETS_ROOT, '..', 'node_modules'))
@@ -48,6 +49,7 @@ PIPELINE = build_pipeline_settings(
 
 
 INSTALLED_APPS = [
+    'django.contrib.admin',
     'django.contrib.auth',
     'django.contrib.contenttypes',
     'django.contrib.sites',
