@@ -1,11 +1,7 @@
 """Database models for storing site configuration."""
 
-from __future__ import unicode_literals
-
 from django.contrib.sites.models import Site
 from django.db import models
-from django.utils import six
-from django.utils.encoding import python_2_unicode_compatible
 
 from djblets.cache.synchronizer import GenerationSynchronizer
 from djblets.db.fields import JSONField
@@ -49,7 +45,6 @@ class SiteConfigSettingsWrapper(object):
         return self.siteconfig.get(name)
 
 
-@python_2_unicode_compatible
 class SiteConfiguration(models.Model):
     """Stored version and settings data for a Django site.
 
@@ -108,7 +103,7 @@ class SiteConfiguration(models.Model):
         cls.add_global_defaults({key: default_value})
 
     @classmethod
-    def remove_global_default(self, key):
+    def remove_global_default(cls, key):
         """Remove a global default value for a settings key.
 
         Args:
@@ -118,7 +113,7 @@ class SiteConfiguration(models.Model):
         _GLOBAL_DEFAULTS.pop(key)
 
     @classmethod
-    def clear_global_defaults(self):
+    def clear_global_defaults(cls):
         """Clear all default values for this site configuration.
 
         This will clear only global defaults. This will not affect defaults
@@ -319,7 +314,7 @@ class SiteConfiguration(models.Model):
             unicode:
             The string representation of the site configuration.
         """
-        return "%s (version %s)" % (six.text_type(self.site), self.version)
+        return "%s (version %s)" % (str(self.site), self.version)
 
     class Meta:
         # Djblets 0.9+ sets an app label of "djblets_siteconfig" on
