@@ -1,14 +1,12 @@
 """Views for working with site configurations."""
 
-from __future__ import unicode_literals
-
 from django.contrib.admin.views.decorators import staff_member_required
 from django.http import HttpResponseRedirect
+from django.shortcuts import render
 from django.views.decorators.csrf import csrf_protect
 
 from djblets.siteconfig.forms import SiteSettingsForm
 from djblets.siteconfig.models import SiteConfiguration
-from djblets.util.compat.django.shortcuts import render
 
 
 @csrf_protect
@@ -55,6 +53,7 @@ def site_settings(request,
 
     context = {
         'form': form,
+        'opts': siteconfig._meta,
         'saved': request.GET.get('saved', 0)
     }
     context.update(extra_context)
