@@ -1,81 +1,39 @@
-#
-# testing.py -- Some classes useful for unit testing django-based applications
-#
-# Copyright (c) 2007-2010  Christian Hammond
-# Copyright (c) 2007-2010  David Trowbridge
-#
-# Permission is hereby granted, free of charge, to any person obtaining
-# a copy of this software and associated documentation files (the
-# "Software"), to deal in the Software without restriction, including
-# without limitation the rights to use, copy, modify, merge, publish,
-# distribute, sublicense, and/or sell copies of the Software, and to
-# permit persons to whom the Software is furnished to do so, subject to
-# the following conditions:
-#
-# The above copyright notice and this permission notice shall be included
-# in all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
-# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
-# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
-# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
-# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
-# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
+"""Base class for test cases in Django-based applications."""
 
-from __future__ import print_function, unicode_literals
-
-import importlib
 import inspect
 import os
 import re
 import socket
 import sys
 import threading
-import types
 import warnings
 from collections import OrderedDict
 from contextlib import contextmanager
 from importlib import import_module
+from importlib.machinery import ModuleSpec
+from importlib.util import module_from_spec
 from unittest.util import safe_repr
 
-try:
-    # Python >= 3.4
-    from importlib.machinery import ModuleSpec
-
-    try:
-        # Python >= 3.5
-        from importlib.util import module_from_spec
-    except ImportError:
-        # Python < 3.5
-        module_from_spec = None
-except ImportError:
-    # Python < 3.4
-    ModuleSpec = None
-    module_from_spec = None
-
+import kgb
+from django.apps import apps
 from django.conf import settings
 from django.core import serializers
-from django.core.exceptions import ValidationError
+from django.core.exceptions import EmptyResultSet, ValidationError
 from django.core.handlers.wsgi import WSGIHandler
 from django.core.management import call_command
 from django.core.servers import basehttp
 from django.db import (DatabaseError, DEFAULT_DB_ALIAS, IntegrityError,
                        connections, router)
-from django.db.models import Model
+from django.db.models import Model, Q
+from django.db.models.query import MAX_GET_RESULTS
+from django.db.models.signals import pre_delete
+from django.db.models.sql.compiler import (SQLCompiler,
+                                           SQLDeleteCompiler,
+                                           SQLInsertCompiler,
+                                           SQLUpdateCompiler)
+from django.db.models.sql.query import Query as SQLQuery
 from django.template import Node
 from django.test import testcases
-from django.utils import six
-
-try:
-    # Django >= 1.7
-    from django.apps import apps
-except ImportError:
-    # Django < 1.7
-    from django.db.models.loading import cache as app_cache, load_app
-
-    apps = None
 
 try:
     from django_evolution.models import Evolution, Version
@@ -163,7 +121,7 @@ class TestCase(testcases.TestCase):
 
         old_settings = {}
 
-        for key, value in six.iteritems(settings):
+        for key, value in settings.items():
             old_settings[key] = siteconfig.get(key)
             siteconfig.set(key, value)
 
@@ -172,7 +130,7 @@ class TestCase(testcases.TestCase):
         try:
             yield
         finally:
-            for key, value in six.iteritems(old_settings):
+            for key, value in old_settings.items():
                 siteconfig.set(key, value)
 
             siteconfig.save()
@@ -198,7 +156,7 @@ class TestCase(testcases.TestCase):
             AssertionError:
                 An attribute was not found or the value did not match.
         """
-        for key, value in six.iteritems(attrs):
+        for key, value in attrs.items():
             try:
                 attr_value = getattr(obj, key)
 
@@ -235,7 +193,7 @@ class TestCase(testcases.TestCase):
                 Additional keyword arguments to pass to
                 :py:meth:`assertRaisesMessage`.
         """
-        if isinstance(expected_messages, six.string_types):
+        if isinstance(expected_messages, str):
             expected_messages = [expected_messages]
 
         return self.assertRaisesMessage(ValidationError,
@@ -255,9 +213,9 @@ class TestCase(testcases.TestCase):
         # passing it down to assertRaisesRegex. Python 2.7.9/10's
         # implementation defaults callable_obj to a special value, which
         # Django overrides.
-        return six.assertRaisesRegex(
-            self, expected_exception, re.escape(expected_message),
-            *args, **kwargs)
+        return self.assertRaisesRegex(expected_exception,
+                                      re.escape(expected_message),
+                                      *args, **kwargs)
 
     @contextmanager
     def assertWarns(self, cls=DeprecationWarning, message=None):
@@ -297,7 +255,7 @@ class TestCase(testcases.TestCase):
             self.assertTrue(issubclass(w[-1].category, cls))
 
             if message is not None:
-                self.assertEqual(message, six.text_type(w[-1].message))
+                self.assertEqual(message, str(w[-1].message))
 
     @contextmanager
     def assertNoWarnings(self):
@@ -324,6 +282,482 @@ class TestCase(testcases.TestCase):
 
             self.assertEqual(len(w), 0)
 
+    @contextmanager
+    def assertQueries(self, queries, num_statements=None):
+        """Assert the number and complexity of queries.
+
+        This provides advanced checking of queries, allowing the caller to
+        match filtering, JOINs, ordering, selected fields, and more.
+
+        This takes a list of dictionaries with query information. Each
+        contains the following:
+
+        Keys:
+            model (type):
+                The model representing the results that would be returned
+                or altered by the query.
+
+            annotations (dict, optional):
+                A dictionary containing applied annotations.
+
+                Keys are destination attribute names, and values are the
+                annotation instances.
+
+                The default is empty.
+
+            distinct (bool, optional):
+                Whether :py:meth:`django.db.models.query.QuerySet.distinct`
+                was used.
+
+                The default is ``False``.
+
+            distinct_fields (tuple of str, optional):
+                A list of fields passed to
+                :py:meth:`django.db.models.query.QuerySet.distinct`.
+
+                The default is empty.
+
+            extra (dict, optional):
+                State passed in calls to
+                :py:meth:`django.db.models.query.QuerySet.extra` when using
+                ``select`` and ``select_params``.
+
+                Each key maps to a key in ``select``, and each value is a
+                tuple containing the value in ``select`` and the corresponding
+                value (if any) in ``select_params``.
+
+                Values are normalized to collapse and strip whitespace, to
+                help with comparison.
+
+                The default is empty.
+
+            extra_order_by (list of str, optional):
+                State passed in calls to
+                :py:meth:`django.db.models.query.QuerySet.extra` when using
+                ``order_by``.
+
+                The default is empty.
+
+            extra_tables (list of str, optional):
+                State passed in calls to
+                :py:meth:`django.db.models.query.QuerySet.extra` when using
+                ``tables``.
+
+                The default is empty.
+
+            group_by (bool or tuple, optional):
+                Whether no fields will be grouped (``None``), all fields will
+                be grouped (``True``), or specific expressions/field names are
+                grouped (a tuple).
+
+                This is influenced by using
+                :py:meth:`django.db.models.query.QuerySet.annotate`.
+
+                The default is ``None``.
+
+            limit (int, optional):
+                The value for a ``LIMIT`` in the ``SELECT``.
+
+                This will generally only need to be supplied if testing a
+                query using :py:meth:`QuerySet.exists()
+                <django.db.models.query.QuerySet.exists>` or when slicing
+                results.
+
+                Django itself sometimes uses a default of ``None`` and
+                sometimes a default currently of ``21`` (this exact value,
+                and when it's used, is considered an implementation detail
+                in Django). Both of these will match a caller-provided
+                ``limit`` value of ``None``.
+
+                The default is ``None``.
+
+            num_joins (int, optional):
+                The number of tables JOINed.
+
+                The default is 0.
+
+            offset (int, optional):
+                The value for an ``OFFSET`` in the ``SELECT``.
+
+                The default is 0.
+
+            only_fields (set of str, optional);
+                The specific fields being fetched, or ``None`` if fetching
+                all fields.
+
+                The default is ``None``.
+
+            order_by (tuple of str, optional):
+                The ordering criteria.
+
+                The default is empty.
+
+            select_for_update (bool, optional):
+                Whether this is a select-for-update operation.
+
+                The default is ``False``.
+
+            select_related (set of str, optional):
+                The table names involved in a
+                :py:meth:`django.db.models.query.QuerySet.select_related`.
+
+            subquery (bool, optional):
+                Whether this is considered a subquery of another query.
+
+                The default is ``False``.
+
+            tables (set of str, optional):
+                The tables involved in the query.
+
+                The default is the model's table name.
+
+            type (str, optional):
+                The query type. This would be one of ``DELETE``, ``INSERT``,
+                ``SELECT``, or ``UPDATE``.
+
+                The default is ``SELECT``.
+
+            values_select (list of str, optional):
+                A list of specified fields being returned using
+                :py:meth:`~django.db.models.query.QuerySet.values` or
+                :py:meth:`~django.db.models.query.QuerySet.values_list` or
+
+            where (django.db.models.Q, optional):
+                The query expression objects used to represent the filter on
+                the query.
+
+        Version Added:
+            3.0
+
+        Args:
+            queries (list of dict):
+                The list of query dictionaries to compare executed queries
+                against.
+
+            num_statements (int, optional):
+                The numbre of SQL statements executed.
+
+                This defaults to the length of ``queries``, but callers may
+                need to provide an explicit number, as some operations may add
+                additional database-specific statements (such as
+                transaction-related SQL) that won't be covered in ``queries``.
+
+        Raises:
+            AssertionError:
+                The parameters passed, or the queries compared, failed
+                expectations.
+        """
+        assert isinstance(queries, list)
+
+        if num_statements is None:
+            num_statements = len(queries)
+
+        spy_agency = kgb.SpyAgency()
+
+        executed_queries = []
+        queries_to_qs = {}
+
+        # Track Query objects any time a compiler is executing SQL.
+        @spy_agency.spy_for(SQLCompiler.execute_sql,
+                            owner=SQLCompiler)
+        def _sql_compiler_execute_sql(_self, *args, **kwargs):
+            if isinstance(_self, SQLDeleteCompiler):
+                query_type = 'DELETE'
+            elif isinstance(_self, SQLUpdateCompiler):
+                query_type = 'UPDATE'
+            else:
+                query_type = 'SELECT'
+
+            executed_queries.append((query_type, _self.query))
+
+            return SQLCompiler.execute_sql.call_original(
+                _self, *args, **kwargs)
+
+        @spy_agency.spy_for(SQLInsertCompiler.execute_sql,
+                            owner=SQLInsertCompiler)
+        def _sql_insert_compiler_execute_sql(_self, *args, **kwargs):
+            executed_queries.append(('INSERT', _self.query))
+
+            return SQLInsertCompiler.execute_sql.call_original(
+                _self, *args, **kwargs)
+
+        # Build and track Q() objects any time they're added to a Query.
+        @spy_agency.spy_for(SQLQuery.add_q, owner=SQLQuery)
+        def _query_add_q(_self, q_object):
+            try:
+                queries_to_qs[_self] &= q_object
+            except KeyError:
+                queries_to_qs[_self] = q_object
+
+            return SQLQuery.add_q.call_original(_self, q_object)
+
+        # Copy Q() objects any time a Query is cloned.
+        @spy_agency.spy_for(SQLQuery.clone, owner=SQLQuery)
+        def _query_clone(_self, *args, **kwargs):
+            result = SQLQuery.clone.call_original(_self, *args, **kwargs)
+
+            try:
+                queries_to_qs[result] = queries_to_qs[_self]
+            except KeyError:
+                pass
+
+            return result
+
+        # Set up an explicit pre_delete signal. During deletion, Django
+        # attempts to determine if it can fast-delete (which can be done if,
+        # amongst other things, signals don't need to be emitted for each
+        # object).
+        #
+        # This can lead to inconsistencies in test runs, if registration of
+        # pre_delete or post_delete signals is conditional on that run. We
+        # want to ensure a stable query count and information for DELETEs,
+        # so we deny fast-deletion by setting up a model-global signal handler
+        # during capture of queries.
+        def _on_pre_delete(**kwargs):
+            pass
+
+        pre_delete.connect(_on_pre_delete)
+
+        # Check that the number of SQL queries matches expectations.
+        try:
+            with self.assertNumQueries(num_statements):
+                yield
+        finally:
+            # We no longer need to track anything in the compiler of Query.
+            spy_agency.unspy_all()
+            pre_delete.disconnect(_on_pre_delete)
+
+        # Make sure we received the expected number of Queries.
+        #
+        # First we have to convert each to SQL and see what we get. Any
+        # with EmptyResultSet will be skipped.
+        query_sqls = []
+        norm_executed_queries = []
+
+        for executed_query_info in executed_queries:
+            executed_query = executed_query_info[1]
+
+            # First thing we want to do is grab the SQL. This may fail, and
+            # if it does, it represents a query that we've caught that isn't
+            # actually going to be executed (likely a component of another).
+            try:
+                try:
+                    query_sqls.append([str(executed_query)])
+                except ValueError:
+                    # When doing an INSERT OR IGNORE (SQLite), the SQL
+                    # can be a list rather than a string. Query.__str__
+                    # doesn't know how to handle this, and will crash.
+                    # We'll deal with it ourselves.
+                    sql_statements = executed_query.sql_with_params()
+                    assert isinstance(sql_statements, list)
+
+                    query_sqls.append([
+                        _sql % _sql_params
+                        for _sql, _sql_params in sql_statements
+                    ])
+
+                norm_executed_queries.append(executed_query_info)
+            except EmptyResultSet:
+                # This will be skipped.
+                pass
+
+        executed_queries = norm_executed_queries
+
+        # Now we can compare numbers.
+        error_lines = []
+        num_queries = len(queries)
+        num_executed_queries = len(executed_queries)
+
+        if num_queries != num_executed_queries:
+            error_lines += [
+                '%s queries were provided, but %s were executed.'
+                % (num_queries, num_executed_queries),
+
+                '',
+            ]
+
+            if num_queries < num_executed_queries:
+                queries += [
+                    {}
+                    for _i in range(num_executed_queries - num_queries)
+                ]
+            elif num_queries > num_executed_queries:
+                queries = queries[:num_executed_queries]
+
+        # Go through each matching Query and compare state.
+        ws_re = self.ws_re
+        all_failures = []
+        queries_iter = enumerate(zip(queries, executed_queries, query_sqls))
+
+        for (i,
+             (query_info,
+              (executed_query_type, executed_query),
+              query_sql)) in queries_iter:
+            # Check if this is set to be skipped, as per the above checks.
+            if query_sql is None:
+                continue
+
+            failures = []
+
+            executed_table_name = executed_query.model._meta.db_table
+            executed_reffed_tables = {
+                _table_name
+                for _table_name in executed_query.alias_map.keys()
+                if executed_query.alias_refcount.get(_table_name, 0) > 0
+            }
+
+            # Check 'model'.
+            model = query_info.get('model', None)
+
+            if model is not executed_query.model:
+                failures.append(('model', model, executed_query.model))
+
+            # Check the query type.
+            query_type = query_info.get('type', 'SELECT')
+
+            if query_type != executed_query_type:
+                failures.append(('type', query_type, executed_query_type))
+
+            # Check the fields that are easy to compare.
+            for key, default in (('annotations', {}),
+                                 ('distinct', False),
+                                 ('distinct_fields', ()),
+                                 ('extra_order_by', ()),
+                                 ('extra_tables', ()),
+                                 ('group_by', None),
+                                 ('order_by', ()),
+                                 ('select_for_update', False),
+                                 ('subquery', False),
+                                 ('values_select', ())):
+                value = query_info.get(key, default)
+                executed_value = getattr(executed_query, key)
+
+                if value != executed_value:
+                    failures.append((key, value, executed_value))
+
+            # Check 'extra'.
+            value = {
+                _key: (ws_re.sub(' ', _value[0]).strip(), _value[1])
+                for _key, _value in query_info.get('extra', {}).items()
+            }
+            executed_value = {
+                _key: (ws_re.sub(' ', _value[0]).strip(), _value[1])
+                for _key, _value in executed_query.extra.items()
+            }
+
+            if value != executed_value:
+                failures.append(('extra', value, executed_value))
+
+            # Check 'offset'.
+            value = query_info.get('offset', 0)
+            executed_value = executed_query.low_mark
+
+            if value != executed_value:
+                failures.append(('offset', value, executed_value))
+
+            # Check 'limit'.
+            value = query_info.get('limit', None)
+            executed_value = executed_query.high_mark
+
+            if (value != executed_value and
+                (value is not None or executed_value != MAX_GET_RESULTS)):
+                failures.append(('limit', value, executed_value))
+
+            # Check 'num_joins'.
+            value = query_info.get('num_joins', 0)
+
+            if executed_query.alias_map:
+                # Consider all tables that have been JOINed, ignoring the
+                # main table.
+                executed_value = len(executed_reffed_tables -
+                                     {executed_table_name})
+            else:
+                executed_value = 0
+
+            if value != executed_value:
+                failures.append(('num_joins', value, executed_value))
+
+            # Check 'tables'.
+            if model is None:
+                default = {}
+            else:
+                default = {model._meta.db_table}
+
+            value = set(query_info.get('tables', default))
+
+            if executed_query.alias_refcount:
+                executed_value = executed_reffed_tables | {executed_table_name}
+            else:
+                executed_value = {executed_table_name}
+
+            if value != executed_value:
+                failures.append(('tables', value, executed_value))
+
+            # Check 'only_fields'.
+            value = set(query_info.get('only_fields', set()))
+            executed_value = set(executed_query.deferred_loading[0])
+
+            if value != executed_value:
+                failures.append(('only_fields', value, executed_value))
+
+            # Check 'select_related'.
+            value = set(query_info.get('select_related', set()))
+            executed_value = executed_query.select_related
+
+            if executed_value:
+                executed_value = set(executed_value.keys())
+            else:
+                executed_value = set()
+
+            if value != executed_value:
+                failures.append(('select_related', value, executed_value))
+
+            # Check 'where'. the Q object used to filter.
+            value = query_info.get('where', Q())
+            executed_value = queries_to_qs.get(executed_query, Q())
+
+            if (executed_value and
+                len(executed_value.children) == 1 and
+                isinstance(executed_value.children[0], Q)):
+                # filter() created a Q() containing nothing but a nested Q().
+                # This is annoying to compare, and could always change in the
+                # future. Extract the inner Q() and use that for comparison
+                # purposes.
+                executed_value = executed_value.children[0]
+
+            if value != executed_value:
+                failures.append(('where', value, executed_value))
+
+            if failures:
+                all_failures.append((i, executed_query, failures, query_sql))
+
+        # Check if we found any failures, and include them in an assertion.
+        if all_failures:
+            num_failures = len(all_failures)
+
+            if num_failures == 1:
+                error_lines.append('1 query failed to meet expectations.')
+            else:
+                error_lines.append(
+                    '%s queries failed to meet expectations.'
+                    % num_failures,
+                )
+
+            for i, executed_query, failures, query_sql in all_failures:
+                if failures:
+                    error_lines += [
+                        '',
+                        'Query %s:' % (i + 1),
+                    ] + [
+                        '  %s: %s != %s' % _failure
+                        for _failure in failures
+                    ] + [
+                        '  SQL: %s' % _sql
+                        for _sql in query_sql
+                    ]
+
+            self.fail('\n'.join(error_lines))
+
 
 class TestModelsLoaderMixin(object):
     """Allows unit test modules to provide models to test against.
@@ -333,8 +767,7 @@ class TestModelsLoaderMixin(object):
     tests.
 
     Typically, Django requires any test directories to be pre-added to
-    INSTALLED_APPS, and a models.py made available (in Django < 1.7), in
-    order for models to be created in the test database.
+    INSTALLED_APPS in order for models to be created in the test database.
 
     This mixin works around this by dynamically adding the module to
     INSTALLED_APPS and forcing the database to be synced. It also will
@@ -361,39 +794,24 @@ class TestModelsLoaderMixin(object):
         except ImportError:
             # Set up a 'models' module, containing any models local to the
             # module that this TestCase is in.
-            if ModuleSpec:
-                # Python >= 3.4
-                #
-                # It's not enough to simply create a module type. We need to
-                # create a basic spec, and then we need to have the module
-                # system create a module from it. There's a handy public
-                # function to do this on Python 3.5, but Python 3.4 lacks a
-                # public function. Fortunately, it's easy to call a private
-                # one.
-                spec = ModuleSpec(name=models_mod_name,
-                                  loader=None)
 
-                if module_from_spec:
-                    # Python >= 3.5
-                    models_mod = module_from_spec(spec)
-                else:
-                    # Python == 3.4
-                    models_mod = \
-                        importlib._bootstrap._SpecMethods(spec).create()
+            # It's not enough to simply create a module type. We need to
+            # create a basic spec, and then we need to have the module
+            # system create a module from it. There's a handy public
+            # function to do this on Python 3.5, but Python 3.4 lacks a
+            # public function. Fortunately, it's easy to call a private
+            # one.
+            spec = ModuleSpec(name=models_mod_name,
+                              loader=None)
 
-                assert models_mod
-            else:
-                # Python < 3.4
-                models_mod = types.ModuleType(str(models_mod_name))
-
-                # Django needs a value here. Doesn't matter what it is.
-                models_mod.__file__ = ''
+            models_mod = module_from_spec(spec)
+            assert models_mod
 
             # Transfer all the models over into this new module.
             module_name = cls.__module__
             test_module = sys.modules[module_name]
 
-            for key, value in six.iteritems(test_module.__dict__):
+            for key, value in test_module.__dict__.items():
                 if (inspect.isclass(value) and
                     issubclass(value, Model) and
                     value.__module__ == module_name):
@@ -418,34 +836,30 @@ class TestModelsLoaderMixin(object):
             Version.objects.all().delete()
             Evolution.objects.all().delete()
 
-        if apps:
-            # Push the new set of installed apps, and begin registering
-            # each of the models associated with the tests.
-            apps.set_installed_apps(settings.INSTALLED_APPS)
-            app_config = apps.get_containing_app_config(cls.tests_app)
+        # Push the new set of installed apps, and begin registering
+        # each of the models associated with the tests.
+        apps.set_installed_apps(settings.INSTALLED_APPS)
+        app_config = apps.get_containing_app_config(cls.tests_app)
 
-            if models_mod:
-                app_label = app_config.label
+        if models_mod:
+            app_label = app_config.label
 
-                for key, value in six.iteritems(models_mod.__dict__):
-                    if inspect.isclass(value) and issubclass(value, Model):
-                        # The model was likely registered under another app,
-                        # so we need to remove the old one and add the new
-                        # one.
-                        try:
-                            del apps.all_models[value._meta.app_label][
-                                value._meta.model_name]
-                        except KeyError:
-                            pass
+            for key, value in models_mod.__dict__.items():
+                if inspect.isclass(value) and issubclass(value, Model):
+                    # The model was likely registered under another app,
+                    # so we need to remove the old one and add the new
+                    # one.
+                    try:
+                        del apps.all_models[value._meta.app_label][
+                            value._meta.model_name]
+                    except KeyError:
+                        pass
 
-                        value._meta.app_label = app_label
-                        apps.register_model(app_label, value)
+                    value._meta.app_label = app_label
+                    apps.register_model(app_label, value)
 
-            call_command('migrate', run_syncdb=True, verbosity=0,
-                         interactive=False)
-        else:
-            load_app(cls.tests_app)
-            call_command('syncdb', verbosity=0, interactive=False)
+        call_command('migrate', run_syncdb=True, verbosity=0,
+                     interactive=False)
 
         super(TestModelsLoaderMixin, cls).setUpClass()
 
@@ -466,14 +880,8 @@ class TestModelsLoaderMixin(object):
             except KeyError:
                 pass
 
-        if apps:
-            apps.unset_installed_apps()
-            apps.all_models[cls.tests_app].clear()
-        else:
-            if models_mod:
-                del app_cache.app_store[models_mod]
-
-            app_cache._get_models_cache.clear()
+        apps.unset_installed_apps()
+        apps.all_models[cls.tests_app].clear()
 
         # Set this free so the garbage collector can eat it.
         cls._tests_loader_models_mod = None
@@ -661,7 +1069,7 @@ class FixturesCompilerMixin(object):
                 # everything matching the deserialized objects' IDs and then
                 # bulk-create new entries.
                 try:
-                    for model_cls, objs in six.iteritems(to_save):
+                    for model_cls, objs in to_save.items():
                         obj_ids = [
                             _obj.pk
                             for _obj in objs
@@ -691,7 +1099,7 @@ class FixturesCompilerMixin(object):
                 # need to clear the old list first.
                 for obj, m2m_data in to_save_m2m:
                     try:
-                        for m2m_attr, m2m_objs in six.iteritems(m2m_data):
+                        for m2m_attr, m2m_objs in m2m_data.items():
                             getattr(obj, m2m_attr).add(*m2m_objs)
                     except (DatabaseError, IntegrityError) as e:
                         meta = obj._meta
@@ -718,14 +1126,11 @@ class FixturesCompilerMixin(object):
             list:
             The list of Django applications.
         """
-        if apps:
-            return [
-                app.models_module
-                for app in apps.get_app_configs()
-                if app.models_module
-            ]
-        else:
-            return app_cache.get_apps()
+        return [
+            app.models_module
+            for app in apps.get_app_configs()
+            if app.models_module
+        ]
 
     def __getattribute__(self, name):
         if name == 'fixtures' and self.__dict__.get('_hide_fixtures'):
