@@ -3,7 +3,7 @@
 import datetime
 
 from django.core.serializers.json import DjangoJSONEncoder
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 from django.utils.functional import Promise
 
 
@@ -15,7 +15,6 @@ class DjbletsJSONEncoder(DjangoJSONEncoder):
     following:
 
     * Evaluates strings translated with
-      :py:func:`~django.utils.translation.ugettext_lazy` or
       :py:func:`~django.utils.translation.gettext_lazy` to real strings.
 
     * Removes the milliseconds and microseconds
@@ -54,9 +53,11 @@ class DjbletsJSONEncoder(DjangoJSONEncoder):
             A JSON-compatible structure (e.g., a :py:class:`dict`,
             :py:class:`list`, py:class:`unicode`, or :py:class:`bytes` object).
         """
-        if isinstance(obj, Promise):
-            # Handles initializing lazily created ugettext messages.
-            return force_text(obj)
+        if isinstance(obj, set):
+            return sorted(obj)
+        elif isinstance(obj, Promise):
+            # Handles initializing lazily created gettext messages.
+            return force_str(obj)
         elif isinstance(obj, datetime.datetime) and self.strip_datetime_ms:
             # This is like DjangoJSONEncoder's datetime encoding
             # implementation, except that it filters out the milliseconds
