@@ -1,48 +1,20 @@
-#
-# djblets_utils.py -- Various utility template tags
-#
-# Copyright (c) 2007-2009  Christian Hammond
-# Copyright (c) 2007-2009  David Trowbridge
-#
-# Permission is hereby granted, free of charge, to any person obtaining
-# a copy of this software and associated documentation files (the
-# "Software"), to deal in the Software without restriction, including
-# without limitation the rights to use, copy, modify, merge, publish,
-# distribute, sublicense, and/or sell copies of the Software, and to
-# permit persons to whom the Software is furnished to do so, subject to
-# the following conditions:
-#
-# The above copyright notice and this permission notice shall be included
-# in all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
-# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
-# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
-# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
-# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
-# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-
-from __future__ import unicode_literals
+"""Miscellaneous utility template tags."""
 
 import datetime
 import os
 import re
 import warnings
+from urllib.parse import urlencode
 
 from django import template
 from django.http import QueryDict
 from django.template import TemplateSyntaxError, Variable
 from django.template.defaultfilters import stringfilter
-from django.utils import six
+from django.template.loader import render_to_string
 from django.utils.html import escape, format_html, strip_spaces_between_tags
 from django.utils.safestring import mark_safe
-from django.utils.six.moves import range
-from django.utils.six.moves.urllib.parse import urlencode
 from django.utils.timezone import is_aware
 
-from djblets.deprecation import RemovedInDjblets30Warning
-from djblets.util.compat.django.template.loader import render_to_string
 from djblets.util.decorators import blocktag
 from djblets.util.dates import get_tz_aware_utcnow
 from djblets.util.http import get_url_params_except
@@ -52,7 +24,7 @@ from djblets.util.humanize import humanize_list
 register = template.Library()
 
 
-WS_RE = re.compile('\s+')
+WS_RE = re.compile(r'\s+')
 
 
 @register.tag
@@ -127,8 +99,7 @@ def definevar(context, nodelist, varname, *options):
         result = result.strip()
 
     if 'unsafe' in options:
-        # Unicode strings are inherently "unsafe".
-        result = six.text_type(result)
+        result = escape(result)
     else:
         result = mark_safe(result)
 
@@ -260,7 +231,7 @@ def include_as_string(context, template_name):
            var s = {% include_as_string "message.txt" %};
            </script>
     """
-    s = render_to_string(template_name, context)
+    s = render_to_string(template_name, context.flatten())
     s = s.replace("'", "\\'")
     s = s.replace("\n", "\\\n")
 
@@ -329,7 +300,7 @@ def attr(context, nodelist, attrname, *options):
     if not content:
         return ''
 
-    return format_html(' {0}="{1}"', attrname, six.text_type(content))
+    return format_html(' {0}="{1}"', attrname, str(content))
 
 
 @register.filter
@@ -750,6 +721,8 @@ def paragraphs(text):
             s += "<p>%s</p>\n" % line
 
     return mark_safe(s)
+
+
 paragraphs.is_safe = True
 
 
@@ -782,60 +755,6 @@ def split(s, delim=','):
     return s.split(delim)
 
 
-@register.simple_tag(takes_context=True)
-def querystring_with(context, attr, value):
-    """Return the current page URL with a new query string argument added.
-
-    This makes it easy to add to or replace part of a query string for the
-    current page's URL, which may already contain a query string.
-
-    If the page URL already has a query string, a new item is added in the form
-    of ``&attr=value``. If it doesn't have a query string, this will start a
-    new one in the form of ``?attr=value``.
-
-    If the attribute already exists in the query string, its value will be
-    replaced.
-
-    Args:
-        context (django.template.context.RequestContext):
-            The Django template rendering context.
-
-        attr (unicode):
-            The name of the attribute for the new query string argument.
-
-        value (unicode):
-            The value of the attribute for the new query string argument.
-
-    Returns:
-        unicode:
-        The new URL with the modified query string.
-
-    Example:
-        .. code-block:: html+django
-
-           <a href="{% querystring_with "sorted" "1" %}">Sort</a>
-    """
-    warnings.warn(
-        '{%% querystring_with "%(attr)s" "%(value)s" %%} is deprecated and '
-        'will be removed in a future version of Djblets. Please use '
-        '{%% querystring "mode" "%(attr)s=%(value)s" %%} instead.'
-        % {
-            'attr': attr,
-            'value': value,
-        },
-        RemovedInDjblets30Warning)
-
-    existing_query = get_url_params_except(context['request'].GET, attr)
-    new_query = urlencode({attr.encode('utf-8'): value.encode('utf-8')})
-
-    if existing_query:
-        result = '?%s&%s' % (existing_query, new_query)
-    else:
-        result = '?%s' % new_query
-
-    return escape(result)
-
-
 @register.simple_tag(takes_context=True)
 def querystring(context, mode, *args):
     """Return current page URL with new query string containing multiple
