@@ -1,13 +1,10 @@
 """The base class for an API authentication backend."""
 
-from __future__ import unicode_literals
-
 import logging
 import re
 
 from django.contrib import auth
-from django.utils import six
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 
 from djblets.auth.ratelimit import is_ratelimited
 
@@ -160,7 +157,7 @@ class WebAPIAuthBackend(object):
             'Attempting authentication on API: %s',
             ', '.join([
                 '%s=%s' % pair
-                for pair in six.iteritems(cleaned_credentials)
+                for pair in cleaned_credentials.items()
             ]),
             extra=log_extra)
 
@@ -210,7 +207,7 @@ class WebAPIAuthBackend(object):
         # the user is already logged in, and querying the backend for every
         # request is excessive, so it's a tradeoff. The user already has
         # access to the server at this point anyway.
-        if (request.user.is_authenticated() and
+        if (request.user.is_authenticated and
             request.user.username == credentials.get('username')):
             return True, None, None
 
@@ -232,7 +229,7 @@ class WebAPIAuthBackend(object):
         """
         clean_credentials = {}
 
-        for key, value in six.iteritems(credentials):
+        for key, value in credentials.items():
             if self.SENSITIVE_CREDENTIALS_RE.search(key):
                 clean_credentials[key] = '************'
             else:
