@@ -1,21 +1,19 @@
 """Base class for a resource in an API."""
 
-from __future__ import unicode_literals
-
 import logging
 import warnings
 
-from django.conf.urls import include, url
 from django.core.exceptions import ObjectDoesNotExist
-from django.core.urlresolvers import reverse
 from django.db import models
+from django.db.models.fields.related_descriptors import (
+    ManyToManyDescriptor,
+    ForwardManyToOneDescriptor)
 from django.db.models.query import QuerySet
 from django.http import (HttpResponseNotAllowed, HttpResponse,
                          HttpResponseNotModified)
-from django.utils import six
+from django.urls import include, path, re_path, reverse
 from django.views.decorators.vary import vary_on_headers
 
-from djblets.deprecation import RemovedInDjblets30Warning
 from djblets.auth.ratelimit import (RATE_LIMIT_API_ANONYMOUS,
                                     RATE_LIMIT_API_AUTHENTICATED,
                                     get_usage_count)
@@ -46,26 +44,9 @@ from djblets.webapi.errors import (DOES_NOT_EXIST,
                                    WebAPIError)
 from djblets.webapi.fields import IntFieldType
 
-try:
-    # Django >= 1.9
-    from django.db.models.fields.related_descriptors import (
-        ManyToManyDescriptor,
-        ForwardManyToOneDescriptor)
 
-    m2m_descriptors = (ManyToManyDescriptor,)
-    fkey_descriptors = (ForwardManyToOneDescriptor,)
-except ImportError:
-    # Django < 1.9
-    from django.db.models.fields.related import (
-        ManyRelatedObjectsDescriptor,
-        ReverseManyRelatedObjectsDescriptor,
-        ReverseSingleRelatedObjectDescriptor)
-
-    m2m_descriptors = (
-        ManyRelatedObjectsDescriptor,
-        ReverseManyRelatedObjectsDescriptor,
-    )
-    fkey_descriptors = (ReverseSingleRelatedObjectDescriptor,)
+m2m_descriptors = (ManyToManyDescriptor,)
+fkey_descriptors = (ForwardManyToOneDescriptor,)
 
 
 logger = logging.getLogger(__name__)
@@ -243,7 +224,7 @@ class WebAPIResource(object):
         else:
             view = None
 
-        if view and six.callable(view):
+        if view and callable(view):
             result = self.call_method_view(
                 request, method, view, api_format=api_format, *args, **kwargs)
 
@@ -682,14 +663,14 @@ class WebAPIResource(object):
         return them in the ``urls.py`` files.
         """
         urlpatterns = never_cache_patterns(
-            url(r'^$', self, name=self._build_named_url(self.name_plural)),
+            path('', self, name=self._build_named_url(self.name_plural)),
         )
 
         for resource in self.list_child_resources:
             resource._parent_resource = self
-            child_regex = r'^' + resource.uri_name + r'/'
             urlpatterns += [
-                url(child_regex, include(resource.get_url_patterns())),
+                path(resource.uri_name + '/',
+                     include(resource.get_url_patterns())),
             ]
 
         if self.uri_object_key or self.singleton:
@@ -701,15 +682,15 @@ class WebAPIResource(object):
                 base_regex = r'^'
 
             urlpatterns += never_cache_patterns(
-                url(base_regex + r'$', self,
-                    name=self._build_named_url(self.name))
+                re_path(base_regex + r'$', self,
+                        name=self._build_named_url(self.name))
             )
 
             for resource in self.item_child_resources:
                 resource._parent_resource = self
                 child_regex = base_regex + resource.uri_name + r'/'
                 urlpatterns += [
-                    url(child_regex, include(resource.get_url_patterns())),
+                    re_path(child_regex, include(resource.get_url_patterns())),
                 ]
 
         return urlpatterns
@@ -727,7 +708,7 @@ class WebAPIResource(object):
 
                 return self._parent_resource.has_access_permissions(
                     request, parent_obj, *args, **kwargs)
-            except:
+            except Exception:
                 # Other errors, like Does Not Exist, should be caught
                 # separately. As of here, we'll allow it to pass, so that
                 # the error isn't a Permission Denied when it should be
@@ -749,7 +730,7 @@ class WebAPIResource(object):
         serialize_link_func = getattr(self, 'serialize_%s_link' % field,
                                       None)
 
-        if not serialize_link_func or not six.callable(serialize_link_func):
+        if not serialize_link_func or not callable(serialize_link_func):
             serialize_link_func = self.serialize_link
 
         return serialize_link_func
@@ -787,7 +768,7 @@ class WebAPIResource(object):
             unicode:
             The object's title.
         """
-        return six.text_type(obj)
+        return str(obj)
 
     def serialize_object(self, obj, *args, **kwargs):
         """Serializes the object into a Python dictionary."""
@@ -846,7 +827,7 @@ class WebAPIResource(object):
             # this object and its children.
             child_expanded_resources = expanded_resources.copy()
 
-            for field in six.iterkeys(self.fields):
+            for field in self.fields.keys():
                 if field in expanded_resources:
                     child_expanded_resources.remove(field)
 
@@ -868,7 +849,7 @@ class WebAPIResource(object):
             request._djblets_webapi_expanded_resources = \
                 child_expanded_resources
 
-        for field in six.iterkeys(self.fields):
+        for field in self.fields.keys():
             can_include_field = only_fields is None or field in only_fields
             expand_field = field in expanded_resources
 
@@ -880,7 +861,7 @@ class WebAPIResource(object):
 
             serialize_func = getattr(self, "serialize_%s_field" % field, None)
 
-            if serialize_func and six.callable(serialize_func):
+            if serialize_func and callable(serialize_func):
                 value = serialize_func(obj, request=request)
             else:
                 value = getattr(obj, field)
@@ -986,7 +967,7 @@ class WebAPIResource(object):
         elif only_links != []:
             data['links'] = dict([
                 (link_name, link_info)
-                for link_name, link_info in six.iteritems(links)
+                for link_name, link_info in links.items()
                 if link_name in only_links
             ])
 
@@ -1096,8 +1077,9 @@ class WebAPIResource(object):
                 'href': '%s%s/' % (clean_base_href, resource.uri_name),
             }
 
-        for key, info in six.iteritems(
-                self.get_related_links(obj, request, *args, **kwargs)):
+        related_links = self.get_related_links(obj, request, *args, **kwargs)
+
+        for key, info in related_links.items():
             links[key] = {
                 'method': info['method'],
                 'href': info['href'],
@@ -1245,7 +1227,7 @@ class WebAPIResource(object):
         if self.etag_field:
             return self.encode_etag(
                 request,
-                six.text_type(getattr(obj, self.etag_field)))
+                str(getattr(obj, self.etag_field)))
 
         return None
 
@@ -1257,50 +1239,6 @@ class WebAPIResource(object):
         """
         return encode_etag('%s:%s' % (request.user.username, etag))
 
-    def generate_etag(self, obj, fields, request, encode_etag=True, **kwargs):
-        """Generate an ETag from the serialized values of all given fields.
-
-        .. deprecated:: 2.0
-
-           This method is no longer called internally, as the auto-generation
-           logic for ETags has changed. It's left here for any resources that
-           may still call it, and is scheduled to be removed in a future
-           release.
-
-        Args:
-            obj (object):
-                The object being serialized.
-
-            fields (list of unicode, unused):
-                An unused list of field names. You can provide any value here.
-                It will be ignored.
-
-            request (django.http.HttpRequest):
-                The HTTP request from the client.
-
-            encode_etag (bool, optional):
-                Whether to encode the ETag to a SHA.
-
-            **kwargs (dict):
-                Extra keyword arguments for :py:meth:`serialize_object`.
-
-        Returns:
-            unicode:
-            The generated ETag.
-        """
-        warnings.warn(
-            'WebAPIResource.generate_etag is deprecated and no longer called '
-            'by default. Please provide your own ETag generation in '
-            'get_etag().',
-            RemovedInDjblets30Warning)
-
-        etag = repr(self.serialize_object(obj, request=request, **kwargs))
-
-        if encode_etag:
-            etag = self.encode_etag(request, etag)
-
-        return etag
-
     def are_cache_headers_current(self, request, last_modified=None,
                                   etag=None):
         """Determines if cache headers from the client are current.
@@ -1323,7 +1261,7 @@ class WebAPIResource(object):
         Subclasses can override this to return different or more detailed
         errors.
         """
-        if request.user.is_authenticated():
+        if request.user.is_authenticated:
             logger.warning('%s %s: user %s does not have '
                            'permission to access this resource.',
                            request.method, request.path,
@@ -1388,7 +1326,7 @@ class WebAPIResource(object):
         if not hasattr(self, '_select_related_fields'):
             self._select_related_fields = []
 
-            for field in six.iterkeys(self.fields):
+            for field in self.fields.keys():
                 if hasattr(self, 'serialize_%s_field' % field):
                     continue
 
@@ -1405,7 +1343,7 @@ class WebAPIResource(object):
             if not hasattr(self, '_prefetch_related_fields'):
                 self._prefetch_related_fields = []
 
-                for field in six.iterkeys(self.fields):
+                for field in self.fields.keys():
                     if hasattr(self, 'serialize_%s_field' % field):
                         continue
 
@@ -1437,7 +1375,7 @@ class WebAPIResource(object):
         if isinstance(obj, dict):
             return dict(
                 (key, self._clone_serialized_object(value))
-                for key, value in six.iteritems(obj)
+                for key, value in obj.items()
             )
         elif isinstance(obj, list):
             return [
