@@ -1,12 +1,9 @@
 """A flexible resource for the root of your API resource tree."""
 
-from __future__ import unicode_literals
-
 from collections import namedtuple
 
-from django.conf.urls import url
 from django.http import HttpResponseNotModified
-from django.utils import six
+from django.urls import path
 
 from djblets.urls.patterns import never_cache_patterns
 from djblets.webapi.errors import DOES_NOT_EXIST
@@ -106,7 +103,7 @@ class RootResource(WebAPIResource):
             unassigned_templates = self._registered_uri_templates.get(
                 None, {})
 
-            for name, href in six.iteritems(unassigned_templates):
+            for name, href in unassigned_templates.items():
                 templates[name] = href
 
             for entry in self.walk_resources(self, base_href):
@@ -116,7 +113,7 @@ class RootResource(WebAPIResource):
                     list_templates = self._registered_uri_templates.get(
                         entry.resource, {})
 
-                    for name, href in six.iteritems(list_templates):
+                    for name, href in list_templates.items():
                         templates[name] = '%s%s' % (entry.list_href, href)
 
             self._uri_templates[base_href] = templates
@@ -181,7 +178,8 @@ class RootResource(WebAPIResource):
         generic catch-all 404 handler which returns API errors instead of HTML.
         """
         urlpatterns = super(RootResource, self).get_url_patterns()
-        urlpatterns += never_cache_patterns(url(r'.*', self.api_404_handler))
+        urlpatterns += never_cache_patterns(
+            path('<str>', self.api_404_handler))
 
         return urlpatterns
 
